@@ -1,26 +1,30 @@
-from typing import Sequence
+from typing import Optional, Sequence
 from smtplib import SMTPException
 import logging
 
-from django.conf import settings
 from django.core.mail import EmailMessage
 
+from django_drf_utils.config import Email
 from django_drf_utils.exceptions import ServiceUnavailable
 
 logger = logging.getLogger(__name__)
 
 
-def sendmail(subject: str, body: str, recipients: Sequence[str], **kwargs):
+def sendmail(
+    subject: str,
+    body: str,
+    recipients: Sequence[str],
+    email_cfg: Optional[Email],
+    **kwargs,
+):
     if not recipients:
         return
     try:
         EmailMessage(
-            subject=(
-                settings.CONFIG.email and settings.CONFIG.email.subject_prefix or ""
-            )
-            + subject,
+            subject=(email_cfg and email_cfg.subject_prefix or "") + subject,
             body=body,
-            from_email=settings.CONFIG.email and settings.CONFIG.email.from_address,
+            # mypy doesn't like the simpler `email_cfg and email_cfg.from_address` statement
+            from_email=None if email_cfg is None else email_cfg.from_address,
             to=recipients,
             **kwargs,
         ).send(fail_silently=False)
