@@ -1,6 +1,5 @@
 from typing import Type
 
-from assertpy import assert_that
 from django.core.exceptions import ValidationError
 from django.db import models
 
@@ -13,10 +12,14 @@ def validate_field(
     validation_errors = get_validation_errors(model_instance)
     if expected:
         # field should NOT raise an error
-        assert_that(validation_errors).does_not_contain(field_name)
+        assert (  # nosec
+            field_name not in validation_errors
+        ), f"'{field_name}' should NOT be in '{validation_errors}'."
     else:
         # field should raise an error
-        assert_that(validation_errors).contains(field_name)
+        assert (  # nosec
+            field_name in validation_errors
+        ), f"'{field_name}' should be in '{validation_errors}'."
 
 
 # TODO contribute to django / pytest
